/**
 * Using Rails-like standard naming convention for endpoints.
 * GET     /api/Shifts              ->  index
 * POST    /api/Shifts              ->  create
 * GET     /api/Shifts/:id          ->  show
 * PUT     /api/Shifts/:id          ->  update
 * DELETE  /api/Shifts/:id          ->  destroy
 */

'use strict';

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.index = index;
exports.show = show;
exports.getShitsbyDocId = getShitsbyDocId;
exports.create = create;
exports.update = update;
exports.destroy = destroy;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _sqldb = require('../../sqldb');

function respondWithResult(res, statusCode) {
  statusCode = statusCode || 200;
  return function (entity) {
    if (entity) {
      res.status(statusCode).json(entity);
    }
  };
}

function saveUpdates(updates) {
  return function (entity) {
    return entity.updateAttributes(updates).then(function (updated) {
      return updated;
    });
  };
}

function removeEntity(res) {
  return function (entity) {
    if (entity) {
      return entity.destroy().then(function () {
        res.status(204).end();
      });
    }
  };
}

function handleEntityNotFound(res) {
  return function (entity) {
    if (!entity) {
      res.status(404).end();
      return null;
    }
    return entity;
  };
}

function handleError(res, statusCode) {
  statusCode = statusCode || 500;
  return function (err) {
    res.status(statusCode).send(err);
  };
}

// Gets a list of Settingss

function index(req, res) {
  _sqldb.Shifts.findAll().then(respondWithResult(res))['catch'](handleError(res));
}

// Gets a single Shifts from the DB

function show(req, res) {
  _sqldb.Shifts.find({
    where: {
      _id: req.params.id
    }
  }).then(handleEntityNotFound(res)).then(respondWithResult(res))['catch'](handleError(res));
}

// Gets a single Shifts from the DB

function getShitsbyDocId(req, res) {
  _sqldb.Shifts.findAll({
    where: {
      UserId: req.params.docId
    },
    attributes: ['_id', 'start', 'end', 'dow']
  }).then(handleEntityNotFound(res)).then(respondWithResult(res))['catch'](handleError(res));
}

// Creates a new Shifts in the DB

function create(req, res) {
  _sqldb.Shifts.create(req.body).then(respondWithResult(res, 201))['catch'](handleError(res));
}

// Updates an existing Shifts in the DB

function update(req, res) {
  if (req.body._id) {
    delete req.body._id;
  }
  _sqldb.Shifts.find({
    where: {
      _id: req.params.id
    }
  }).then(handleEntityNotFound(res)).then(saveUpdates(req.body)).then(respondWithResult(res))['catch'](handleError(res));
}

// Deletes a Shifts from the DB

function destroy(req, res) {
  _sqldb.Shifts.find({
    where: {
      _id: req.params.id
    }
  }).then(handleEntityNotFound(res)).then(removeEntity(res))['catch'](handleError(res));
}
//# sourceMappingURL=shifts.controller.js.map
