'use strict';

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports.index = index;
exports.getPhysicians = getPhysicians;
exports.getPhysiciansData = getPhysiciansData;
exports.getPatients = getPatients;
exports.create = create;
exports.update = update;
exports.show = show;
exports.destroy = destroy;
exports.changePassword = changePassword;
exports.forgotPassword = forgotPassword;
exports.me = me;
exports.resetPassword = resetPassword;
exports.authCallback = authCallback;

var _sqldb = require('../../sqldb');

var _passport = require('passport');

var _passport2 = _interopRequireDefault(_passport);

var _configEnvironment = require('../../config/environment');

var _configEnvironment2 = _interopRequireDefault(_configEnvironment);

var _jsonwebtoken = require('jsonwebtoken');

var _jsonwebtoken2 = _interopRequireDefault(_jsonwebtoken);

var _async = require('async');

var _async2 = _interopRequireDefault(_async);

var _crypto = require('crypto');

var _crypto2 = _interopRequireDefault(_crypto);

var nodemailer = require('nodemailer');
var sgTransport = require('nodemailer-sendgrid-transport');
var options = {
	auth: {
		api_user: '<API USER>',
		api_key: '<API KEY>'
	}
};
var client = nodemailer.createTransport(sgTransport(options));

function validationError(res, statusCode) {
	statusCode = statusCode || 422;
	return function (err) {
		res.status(statusCode).json(err);
	};
}

function respondWithResult(res, statusCode) {
	statusCode = statusCode || 200;
	return function (entity) {
		if (entity) {
			res.status(statusCode).json(entity);
		}
	};
}

function saveUpdates(updates) {
	return function (entity) {
		return entity.updateAttributes(updates).then(function (updated) {
			return updated;
		});
	};
}

function removeEntity(res) {
	return function (entity) {
		if (entity) {
			return entity.destroy().then(function () {
				res.status(204).end();
			});
		}
	};
}

function handleEntityNotFound(res) {
	return function (entity) {
		if (!entity) {
			res.status(404).end();
			return null;
		}
		return entity;
	};
}

function handleError(res, statusCode) {
	statusCode = statusCode || 500;
	return function (err) {
		res.status(statusCode).send(err);
	};
}
/**
 * Get list of users
 * restriction: 'admin'
 */

function index(req, res) {
	_sqldb.User.findAll({
		attributes: ['_id', 'first_name', 'last_name', 'age', 'gender', 'birthdate', 'email', 'mobile', 'role', 'npi', 'provider']
	}).then(function (users) {
		res.status(200).json(users);
	})['catch'](handleError(res));
}

function getPhysicians(req, res) {
	_sqldb.User.findAll({
		where: {
			"role": "physician"
		},
		attributes: ['_id', 'first_name', 'last_name', 'email', 'role', 'npi', 'provider']
	}).then(function (users) {
		res.status(200).json(users);
	})['catch'](handleError(res));
}

function getPhysiciansData(req, res) {
	_sqldb.User.findAll({
		where: {
			"role": "physician"
		},
		attributes: ['_id', 'first_name', 'last_name', 'email', 'npi', 'mobile'],
		include: [{
			model: _sqldb.Appointment,
			attributes: ['title', 'start', 'end', '_id'],
			include: [{
				model: _sqldb.User,
				as: 'Patient',
				attributes: ['first_name', 'last_name', 'email', 'mobile', 'gender', '_id']
			}]
		}]
	}).then(function (users) {
		res.status(200).json(users);
	})['catch'](handleError(res));
}

function getPatients(req, res) {
	_sqldb.User.findAll({
		where: {
			"role": "patient"
		},
		attributes: ['_id', 'first_name', 'last_name', 'email', 'mobile']
	}).then(function (users) {
		res.status(200).json(users);
	})['catch'](handleError(res));
}

/**
 * Creates a new user
 */

function create(req, res, next) {
	var newUser = _sqldb.User.build(req.body);
	newUser.setDataValue('provider', 'local');
	newUser.setDataValue('role', req.body.role);
	newUser.save().then(function (user) {
		var token = _jsonwebtoken2['default'].sign({
			_id: user._id
		}, _configEnvironment2['default'].secrets.session, {
			expiresIn: 60 * 60 * 5
		});
		res.json({
			token: token
		});
	})['catch'](validationError(res));
}

// Updates an existing User in the DB

function update(req, res) {
	if (req.body._id) {
		delete req.body._id;
	}
	return _sqldb.User.find({
		where: {
			_id: req.params.id
		}
	}).then(handleEntityNotFound(res)).then(saveUpdates(req.body)).then(respondWithResult(res))['catch'](handleError(res));
}

/**
 * Get a single user
 */

function show(req, res, next) {
	var userId = req.params.id;

	_sqldb.User.find({
		where: {
			_id: userId
		}
	}).then(function (user) {
		if (!user) {
			return res.status(404).end();
		}
		res.json(user.profile);
	})['catch'](function (err) {
		return next(err);
	});
}

/**
 * Deletes a user
 * restriction: 'admin'
 */

function destroy(req, res) {
	_sqldb.User.destroy({
		_id: req.params.id
	}).then(function () {
		res.status(204).end();
	})['catch'](handleError(res));
}

/**
 * Change a users password
 */

function changePassword(req, res, next) {
	var userId = req.user._id;
	var oldPass = String(req.body.oldPassword);
	var newPass = String(req.body.newPassword);

	_sqldb.User.find({
		where: {
			_id: userId
		}
	}).then(function (user) {
		if (user.authenticate(oldPass)) {
			user.password = newPass;
			return user.save().then(function () {
				res.status(204).end("Password successfully changed.");
			})['catch'](validationError(res));
		} else {
			return res.status(403).end("password is incorrect.");
		}
	});
}

function forgotPassword(req, res, next) {
	if (!req.body.email) {
		return res.status(500).json({
			msg: 'Please enter a valid email address.',
			status: 'failure',
			err: errors
		});
	}

	var email = String(req.body.email);
	_async2['default'].waterfall([function (done) {
		_crypto2['default'].randomBytes(16, function (err, buf) {
			var token = buf.toString('hex');
			done(err, token);
		});
	}, function (token, done) {

		_sqldb.User.find({
			where: {
				email: email
			},
			attributes: ['_id', 'first_name', 'last_name', 'email', 'password']
		}).then(function (user) {
			if (!user) {
				return res.status(500).json({
					message: 'No account exists with the provided email address.',
					success: false
				});
			}
			user.resetToken = token;
			user.resetTokenExpires = Date.now() + 3600000; // 1 hour

			user.save().then(function () {
				done(null, token, user);
			})['catch'](function () {
				done(null, token, user);
			});
		});
	}, function (token, user, done) {
		var email = {
			from: 'appointerx@dcoderx.com',
			to: user.email,
			subject: 'Forgot Password',
			text: 'You are receiving this email because you (or someone else) have requested the reset of the password for your account.\n\n' + 'Please click on the following link, or paste this into your browser to complete the process:\n\n' + 'http://' + req.headers.host + '/reset/' + token + '\n\n' + 'If you did not request this, please ignore this email and your password will remain unchanged.\n',
			html: 'You are receiving this email because you (or someone else) have requested the reset of the password for your account.\n\n' + 'Please click on the following link, or paste this into your browser to complete the process:\n\n' + 'http://' + req.headers.host + '/reset/' + token + '\n\n' + 'If you did not request this, please ignore this email and your password will remain unchanged.\n'
		};

		client.sendMail(email, function (err, info) {
			console.dir(info);
			done(err, 'done');
		});
	}], function (err, result) {
		if (err) {
			return res.status(500).json({
				message: 'Error! Please try again.',
				success: false,
				err: err
			});
		}
		return res.status(200).json({
			success: true,
			message: 'An e-mail has been sent to ' + req.body.email.toLowerCase() + ' with further instructions.'
		});
	});
}

/**
 * Get my info
 */

function me(req, res, next) {
	var userId = req.user._id;

	_sqldb.User.find({
		where: {
			_id: userId
		},
		attributes: ['_id', 'first_name', 'last_name', 'email', 'role', 'gender', 'mobile', 'age', 'npi', 'zip', 'address1', 'address2', 'city', 'state', 'zip', 'country', 'provider', 'createdAt']
	}).then(function (user) {
		// don't ever give out the password or salt
		if (!user) {
			return res.status(401).end();
		}
		res.json(user);
	})['catch'](function (err) {
		return next(err);
	});
}

/**
 * Password reset
 * @param object req
 * @param object res
 * @param object next
 * @returns {undefined}
 */

function resetPassword(req, res, next) {
	_sqldb.User.find({
		where: {
			resetToken: req.params.token,
			resetTokenExpires: {
				$gt: Date.now()
			}
		}
	}).then(function (user) {
		// don't ever give out the password or salt
		if (!user) {
			return res.status(401).json({
				message: 'user not found.',
				success: false,
				reason: 'expire'
			});
		}

		user.password = req.body.password;
		user.resetToken = null;
		user.resetTokenExpires = null;
		return user.save().then(function () {
			res.status(204).json({
				message: 'pass reset done',
				success: true

			});
		})['catch'](validationError(res));
	})['catch'](function (err) {
		return next(err);
	});
}

/**
 * Authentication callback
 */

function authCallback(req, res, next) {
	res.redirect('/');
}
//# sourceMappingURL=user.controller.js.map
