'use strict';

var path = require('path');
var _ = require('lodash');

function requiredProcessEnv(name) {
	if (!process.env[name]) {
		throw new Error('You must set the ' + name + ' environment variable');
	}
	return process.env[name];
}

// All configurations will extend these options
// ============================================
var all = {
	env: process.env.NODE_ENV,

	// Root path of server
	root: path.normalize(__dirname + '/../../..'),

	// Server port
	port: process.env.PORT || 9000,

	// Server IP
	ip: process.env.IP || '0.0.0.0',

	// Should we populate the DB with sample data?
	seedDB: false,

	// Secret for session, you will want to change this and make it an environment variable
	secrets: {
		session: 'msql-admin-secret'
	},
	mysql: {
		options: {
			dialect: 'mysql',
			protocol: 'mysql',
			dialectOptions: {
				ssl: false
			},
			pool: { maxIdleTime: 10000, maxConnections: 5, minConnections: 2 },
			storage: {},
			PORT: 3000, // capital PORT allows auto override by common env variable if it exists
			FORCE_DB_SYNC: "false", // must be string to allow environment variable override
			enableSequelizeLog: "true", // type chosen as string for no particular reason
			expressSessionSecret: '$uper$ecret$e$$ionKey' // replace with your own in production
		}
	}

};

// Export the config object based on the NODE_ENV
// ==============================================
module.exports = _.merge(all, require('./shared'), require('./' + process.env.NODE_ENV + '.js') || {});
//# sourceMappingURL=index.js.map
