/**
 * Socket.io configuration
 */
'use strict';

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});

var _environment = require('./environment');

var _environment2 = _interopRequireDefault(_environment);

// When the user disconnects.. perform this
function onDisconnect(socket) {}

// When the user connects.. perform this
function onConnect(socket) {
	// When the client emits 'info', this listens and executes
	socket.on('info', function (data) {
		socket.log(JSON.stringify(data, null, 2));
	});

	// Insert sockets below
	require('../api/patient/patient.socket').register(socket);

	require('../api/shifts/shifts.socket').register(socket);
	require('../api/appointment/appointment.socket').register(socket);
}

exports['default'] = function (socketio) {
	// socket.io (v1.x.x) is powered by debug.
	// In order to see all the debug output, set DEBUG (in server/config/local.env.js) to including the desired scope.
	//
	// ex: DEBUG: "http*,socket.io:socket"

	// We can authenticate socket.io users and access their token through socket.decoded_token
	//
	// 1. You will need to send the token in `client/components/socket/socket.service.js`
	//
	// 2. Require authentication here:
	// socketio.use(require('socketio-jwt').authorize({
	//   secret: config.secrets.session,
	//   handshake: true
	// }));

	socketio.on('connection', function (socket) {
		socket.address = socket.request.connection.remoteAddress + ':' + socket.request.connection.remotePort;

		socket.connectedAt = new Date();

		socket.log = function () {
			for (var _len = arguments.length, data = Array(_len), _key = 0; _key < _len; _key++) {
				data[_key] = arguments[_key];
			}

			console.log.apply(console, ['SocketIO ' + socket.nsp.name + ' [' + socket.address + ']'].concat(data));
		};

		// Call onDisconnect.
		socket.on('disconnect', function () {
			onDisconnect(socket);
			socket.log('DISCONNECTED');
		});

		// Call onConnect.
		onConnect(socket);
		socket.log('CONNECTED');
	});
};

module.exports = exports['default'];
//# sourceMappingURL=socketio.js.map
