/**
 * Sequelize initialization module
 */

'use strict';

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _configEnvironment = require('../config/environment');

var _configEnvironment2 = _interopRequireDefault(_configEnvironment);

var _sequelize = require('sequelize');

var _sequelize2 = _interopRequireDefault(_sequelize);

var onHeroku = !!process.env.DYNO;

var db = {
	Sequelize: _sequelize2['default'],
	sequelize: new _sequelize2['default'](_configEnvironment2['default'].mysql.uri, _configEnvironment2['default'].mysql.options)
};

// Insert models below
db.Patient = db.sequelize['import']('../api/patient/patient.model');
db.SalonService = db.sequelize['import']('../api/salonservice/salonservice.model');
db.Shifts = db.sequelize['import']('../api/shifts/shifts.model');
db.Appointment = db.sequelize['import']('../api/appointment/appointment.model');
db.User = db.sequelize['import']('../api/user/user.model');

// Table Relationships will go here

db.User.hasMany(db.Shifts, {
	foreignKey: 'UserId'
});
db.Shifts.belongsTo(db.User, {
	as: 'settings',
	foreignKey: 'UserId',
	targetKey: '_id',
	constraints: false
});

db.User.hasMany(db.Appointment, {
	foreignKey: 'UserId'
});
db.Appointment.belongsTo(db.User, {
	as: 'creator',
	foreignKey: 'UserId',
	targetKey: '_id',
	constraints: false
});

db.User.hasMany(db.Appointment, {
	foreignKey: 'PatientId'
});
db.Appointment.belongsTo(db.User, {
	as: 'Patient',
	foreignKey: 'PatientId',
	targetKey: '_id',
	constraints: false
});

db.User.hasMany(db.Appointment, {
	foreignKey: 'PhysicianId'
});
db.Appointment.belongsTo(db.User, {
	as: 'Physician',
	foreignKey: 'PhysicianId',
	targetKey: '_id',
	constraints: false
});
// Relationship ends

exports['default'] = db;
module.exports = exports['default'];
//# sourceMappingURL=index.js.map
